powered by
Feature selection function used in the sigma delta space
compute_ax(dm, sv, p)
numeric value, score used for feature selection
delta (difference in mean values)
sigma (sum of variance values)
even number, the greater 'p' is the more importance will be given to sigma