Predict outcome from a CimpleG signatures on new data
# S3 method for CimpleG
predict(object, ..., new_data, class_labels = NULL)prediction object, list with an entry for each signature
CimpleG object.
Not used at the moment.
Data to be predicted, samples should be in rows and features in columns. Last column of `new_data` should have the target/class labels coded as 0 or 1.
Class labels of new data if these are not provided directly with it.